--
-- ESLimiter v2.0
-- Specialization for ESLimiter
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date:		29/08/10
-- @version:	v2.0
-- @history:	v1.0 - initial implementation
--				v2.0 - convert to LS2011 and some bugfixes
-- modifica by spettro v. 0.5

ESLimiter = {};

function ESLimiter.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function ESLimiter:load(xmlFile)

	self.ESLimiter = {};
	self.ESLimiter.xPos = Utils.getNoNil(getXMLFloat(xmlFile,  "vehicle.ESLimiter#posX"), 0.7543);
	self.ESLimiter.yPos = Utils.getNoNil(getXMLFloat(xmlFile,  "vehicle.ESLimiter#posY"), 0.1715);
	self.ESLimiter.maxRPM = {};
	self.ESLimiter.percentage = {};
	for k,v in pairs(self.motor.maxRpm) do
		self.ESLimiter.maxRPM[k] = self.motor.maxRpm[3];
		local percentage = string.format("%d",(self.motor.maxRpm[k]* 100 / self.motor.maxRpm[3]));
		self.ESLimiter.percentage[k] = tonumber(percentage); -- percentage
	end;

	self.eslOverlay = Overlay:new("hudESLOverlay", Utils.getFilename("ESLimiter_hud.dds", self.baseDirectory), self.ESLimiter.xPos, self.ESLimiter.yPos, 0.2371, 0.039525);
end;

function ESLimiter:delete()
end;

function ESLimiter:mouseEvent(posX, posY, isDown, isUp, button)
end;

function ESLimiter:keyEvent(unicode, sym, modifier, isDown)
end;

function ESLimiter:update(dt)
end;

function ESLimiter:draw()
	if self:getIsActiveForInput() then
		local currentLevel = self.motor.speedLevel;
		if self.movingDirection < 0 then
			currentLevel = 1;
		end;
		if currentLevel ~= 0 then
			local percentage = self.ESLimiter.percentage;
			local currentRPM = self.ESLimiter.maxRPM;
			if InputBinding.isPressed(InputBinding.MENUUP) and percentage[currentLevel] < 100 then
				percentage[currentLevel] = percentage[currentLevel] + 1;
			elseif InputBinding.isPressed(InputBinding.MENUDOWN) and percentage[currentLevel] > 10 then
				percentage[currentLevel] = percentage[currentLevel] - 1;
			end;
			if self.movingDirection > 0 then
				ESLimiterperc = 100 - percentage[currentLevel]
			else
				ESLimiterperc = 0
			end;
		else
			ESLimiterperc = 0;
		end;
	end;
	local currentLevel = self.motor.speedLevel;
	local text = "Deaktiviert";
	if self.movingDirection < 0 then
		currentLevel = 1;
	end;
	if currentLevel ~= 0 then
		local percentage = tonumber(string.format("%d", self.ESLimiter.percentage[currentLevel]));
		if percentage < 100 then
			percentage = " " .. percentage;
		end;
		text = currentLevel .. ":" .. percentage .. "% ";
	end;
	self.eslOverlay:render();
	setTextBold(true);
	setTextAlignment(RenderText.ALIGN_LEFT);
	renderText(self.ESLimiter.xPos + 0.13, self.ESLimiter.yPos + 0.0085, 0.02, text);
	g_currentMission:addExtraPrintText(string.format("ESLimiter_controls").. " " .. InputBinding.getKeyNamesOfDigitalAction(InputBinding.MENUUP) .. "/" .. InputBinding.getKeyNamesOfDigitalAction(InputBinding.MENUDOWN));
end;
